#!/bin/bash
# packager         : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
# source location  : http://curl.haxx.se/download/curl-7.25.0.tar.bz2
# last revised     : 31.03.2012

set -e -u -x

softname='curl'
softversion='7.25.0'
packageversion='72.1'

arch='i486'
cpu='i686'

# log ;)
(

# parameters needed for the build process
buildir=$(pwd)
srcpkg="$buildir/$softname-$softversion.tar.bz2"
src="$buildir/$softname-$softversion"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://curl.haxx.se/download/$softname-$softversion.tar.bz2

# prepare the build result directory
dest="$buildir/$package"
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/usr/doc/$softname-$softversion
mkdir -p $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc
    |-----handy-ruler------------------------------------------------------|
curl: curl (command line URL data transfer tool)
curl:
curl: Curl is a command line tool for transferring data specified with URL
curl: syntax.  The command is designed to work without user interaction or
curl: any kind of interactivity.   Curl offers a busload of useful tricks
curl: like proxy support, user authentication, ftp upload, HTTP post,  SSL
curl: (https:) connections, cookies, file transfer resume and more.
curl:
curl: libcurl is a library that Curl uses to do its job. It is readily
curl: available to be used by your software, too.
curl:
EOF

# check if source is present
if [ -f $softname-$softversion.tar.bz2 ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

# extract the source code
cd $buildir
tar xvf $srcpkg
cd $src

# build

    export CFLAGS="-O2 -march=$arch -mtune=$cpu"
    export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

    ./configure \
      --prefix=/usr \
      --mandir=/usr/man \
      --infodir=/usr/info \
      --sysconfdir=/etc \
      --disable-sspi \
      --build=$arch-slackware-linux

    make
    make install DESTDIR=$dest

# add 'default' files
    cp -a \
      CHANGES COPYING README \
      $dest/usr/doc/$softname-$softversion
    ( cd docs
      rm -rf Makefile* curl-config.1 curl-config.html curl.1 curl.html libcurl
      cp -a \
        BUGS CONTRIBUTE FAQ FEATURES INSTALL INTERNALS MANUAL README.win32 RESOURCES THANKS TODO examples \
        $dest/usr/doc/$softname-$softversion )
  
# Compress Man & Info Pages
gzip -9 $dest/usr/man/man?/*

# Strip
( cd $dest
find $dest | xargs -r file | grep "executable\|shared object" | grep ELF |\
	cut -f 1 -d : | xargs -r strip --strip-unneeded
find $dest | xargs -r file | grep "current ar archive" |\
	cut -f 1 -d : | xargs -r strip -g
)

# ZenBuild
cp $buildir/build-$softname.sh $dest/usr/src/$softname-$softversion

# set target permissions
chown -R root:root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# real packaging work
cd $dest
makepkg -l y -c n $dest.txz

# md5sum signature
cd $buildir
md5sum $package.txz > $package.md5

# .dep
cd $buildir
echo -e "cyrus-sasl,libidn,openldap-client,openssl,zlib" > $package.dep

# generate source file
echo http://zenwalk.pinguix.com/user-accounts/bip/ISO/n/curl/source/build-curl.sh > $package.src
echo $source >> $package.src

# erase
rm -rf $src
rm -rf $dest

# log ;)
) 2>&1 | tee "$softname-$softversion-build.log"
